# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Workspace(BaseModel):
    """
    Workspace
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    name: StrictStr
    projects: Optional[List[Project]] = None
    participants: Optional[List[Participant]] = None
    moderators: Optional[List[Moderator]] = None
    files: Optional[List[File]] = None
    threads: Optional[List[Thread]] = None
    attribute_kind_groups: Optional[List[AttributeKindGroup]] = Field(default=None, alias="attributeKindGroups")
    workspace_members: Optional[List[WorkspaceMember]] = Field(default=None, alias="workspaceMembers")
    notebooks: Optional[List[Notebook]] = None
    default_for_users: Optional[List[User]] = Field(default=None, alias="defaultForUsers")
    default_for_orgs: Optional[List[Org]] = Field(default=None, alias="defaultForOrgs")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "projects", "participants", "moderators", "files", "threads", "attributeKindGroups", "workspaceMembers", "notebooks", "defaultForUsers", "defaultForOrgs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Workspace from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in projects (list)
        _items = []
        if self.projects:
            for _item_projects in self.projects:
                if _item_projects:
                    _items.append(_item_projects.to_dict())
            _dict['projects'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in participants (list)
        _items = []
        if self.participants:
            for _item_participants in self.participants:
                if _item_participants:
                    _items.append(_item_participants.to_dict())
            _dict['participants'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in moderators (list)
        _items = []
        if self.moderators:
            for _item_moderators in self.moderators:
                if _item_moderators:
                    _items.append(_item_moderators.to_dict())
            _dict['moderators'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item_files in self.files:
                if _item_files:
                    _items.append(_item_files.to_dict())
            _dict['files'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in threads (list)
        _items = []
        if self.threads:
            for _item_threads in self.threads:
                if _item_threads:
                    _items.append(_item_threads.to_dict())
            _dict['threads'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attribute_kind_groups (list)
        _items = []
        if self.attribute_kind_groups:
            for _item_attribute_kind_groups in self.attribute_kind_groups:
                if _item_attribute_kind_groups:
                    _items.append(_item_attribute_kind_groups.to_dict())
            _dict['attributeKindGroups'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in workspace_members (list)
        _items = []
        if self.workspace_members:
            for _item_workspace_members in self.workspace_members:
                if _item_workspace_members:
                    _items.append(_item_workspace_members.to_dict())
            _dict['workspaceMembers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in notebooks (list)
        _items = []
        if self.notebooks:
            for _item_notebooks in self.notebooks:
                if _item_notebooks:
                    _items.append(_item_notebooks.to_dict())
            _dict['notebooks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in default_for_users (list)
        _items = []
        if self.default_for_users:
            for _item_default_for_users in self.default_for_users:
                if _item_default_for_users:
                    _items.append(_item_default_for_users.to_dict())
            _dict['defaultForUsers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in default_for_orgs (list)
        _items = []
        if self.default_for_orgs:
            for _item_default_for_orgs in self.default_for_orgs:
                if _item_default_for_orgs:
                    _items.append(_item_default_for_orgs.to_dict())
            _dict['defaultForOrgs'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Workspace from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "projects": [Project.from_dict(_item) for _item in obj["projects"]] if obj.get("projects") is not None else None,
            "participants": [Participant.from_dict(_item) for _item in obj["participants"]] if obj.get("participants") is not None else None,
            "moderators": [Moderator.from_dict(_item) for _item in obj["moderators"]] if obj.get("moderators") is not None else None,
            "files": [File.from_dict(_item) for _item in obj["files"]] if obj.get("files") is not None else None,
            "threads": [Thread.from_dict(_item) for _item in obj["threads"]] if obj.get("threads") is not None else None,
            "attributeKindGroups": [AttributeKindGroup.from_dict(_item) for _item in obj["attributeKindGroups"]] if obj.get("attributeKindGroups") is not None else None,
            "workspaceMembers": [WorkspaceMember.from_dict(_item) for _item in obj["workspaceMembers"]] if obj.get("workspaceMembers") is not None else None,
            "notebooks": [Notebook.from_dict(_item) for _item in obj["notebooks"]] if obj.get("notebooks") is not None else None,
            "defaultForUsers": [User.from_dict(_item) for _item in obj["defaultForUsers"]] if obj.get("defaultForUsers") is not None else None,
            "defaultForOrgs": [Org.from_dict(_item) for _item in obj["defaultForOrgs"]] if obj.get("defaultForOrgs") is not None else None
        })
        return _obj

from keplar_api.models.attribute_kind_group import AttributeKindGroup
from keplar_api.models.file import File
from keplar_api.models.moderator import Moderator
from keplar_api.models.notebook import Notebook
from keplar_api.models.org import Org
from keplar_api.models.participant import Participant
from keplar_api.models.project import Project
from keplar_api.models.thread import Thread
from keplar_api.models.user import User
from keplar_api.models.workspace_member import WorkspaceMember
# TODO: Rewrite to not use raise_errors
Workspace.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.brief_document_version import BriefDocumentVersion
from keplar_api.models.project_audience import ProjectAudience
from keplar_api.models.project_brief import ProjectBrief
from keplar_api.models.project_kind import ProjectKind
from keplar_api.models.screener_question import ScreenerQuestion
from typing import Optional, Set
from typing_extensions import Self

class ProjectConfig(BaseModel):
    """
    ProjectConfig
    """ # noqa: E501
    project_kind: Optional[ProjectKind] = Field(default=None, alias="projectKind")
    prompt_variables: Dict[str, Any] = Field(alias="promptVariables")
    learning_plan: StrictStr = Field(alias="learningPlan")
    brief: Optional[ProjectBrief] = None
    current_brief_version: Optional[BriefDocumentVersion] = Field(default=None, alias="currentBriefVersion")
    brief_document: Optional[StrictStr] = Field(default=None, alias="briefDocument")
    screener_questions: Optional[List[ScreenerQuestion]] = Field(default=None, alias="screenerQuestions")
    audience_settings: Optional[ProjectAudience] = Field(default=None, alias="audienceSettings")
    __properties: ClassVar[List[str]] = ["projectKind", "promptVariables", "learningPlan", "brief", "currentBriefVersion", "briefDocument", "screenerQuestions", "audienceSettings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of brief
        if self.brief:
            _dict['brief'] = self.brief.to_dict()
        # override the default output from pydantic by calling `to_dict()` of current_brief_version
        if self.current_brief_version:
            _dict['currentBriefVersion'] = self.current_brief_version.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in screener_questions (list)
        _items = []
        if self.screener_questions:
            for _item_screener_questions in self.screener_questions:
                if _item_screener_questions:
                    _items.append(_item_screener_questions.to_dict())
            _dict['screenerQuestions'] = _items
        # override the default output from pydantic by calling `to_dict()` of audience_settings
        if self.audience_settings:
            _dict['audienceSettings'] = self.audience_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "projectKind": obj.get("projectKind"),
            "promptVariables": obj.get("promptVariables"),
            "learningPlan": obj.get("learningPlan"),
            "brief": ProjectBrief.from_dict(obj["brief"]) if obj.get("brief") is not None else None,
            "currentBriefVersion": BriefDocumentVersion.from_dict(obj["currentBriefVersion"]) if obj.get("currentBriefVersion") is not None else None,
            "briefDocument": obj.get("briefDocument"),
            "screenerQuestions": [ScreenerQuestion.from_dict(_item) for _item in obj["screenerQuestions"]] if obj.get("screenerQuestions") is not None else None,
            "audienceSettings": ProjectAudience.from_dict(obj["audienceSettings"]) if obj.get("audienceSettings") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.join_code_invite302_response import JoinCodeInvite302Response

class TestJoinCodeInvite302Response(unittest.TestCase):
    """JoinCodeInvite302Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JoinCodeInvite302Response:
        """Test JoinCodeInvite302Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JoinCodeInvite302Response`
        """
        model = JoinCodeInvite302Response()
        if include_optional:
            return JoinCodeInvite302Response(
                id = '',
                code = '',
                name = '',
                description = '',
                status = 'PREVIEW',
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project_id = '',
                config = keplar_api.models.code_invite_config.CodeInviteConfig(),
                settings = keplar_api.models.join_code_invite_302_response_settings.joinCodeInvite_302_response_settings(
                    max_duration_seconds = 1.337, 
                    screener_questions = [
                        null
                        ], 
                    files = [
                        keplar_api.models.project_file_public.ProjectFilePublic(
                            file = keplar_api.models.project_file_public_file.ProjectFilePublic_file(
                                description = '', 
                                mime_type = 'image/jpeg', 
                                public_url = '', 
                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            description = '', 
                            metadata = keplar_api.models.project_file_metadata.ProjectFileMetadata(
                                name = '', 
                                prompt = '', 
                                image_description = '', ), )
                        ], 
                    language = 'en', 
                    video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                        enabled = True, 
                        include_audio = True, ), )
            )
        else:
            return JoinCodeInvite302Response(
                id = '',
                code = '',
                name = '',
                status = 'PREVIEW',
                project_id = '',
                config = keplar_api.models.code_invite_config.CodeInviteConfig(),
                settings = keplar_api.models.join_code_invite_302_response_settings.joinCodeInvite_302_response_settings(
                    max_duration_seconds = 1.337, 
                    screener_questions = [
                        null
                        ], 
                    files = [
                        keplar_api.models.project_file_public.ProjectFilePublic(
                            file = keplar_api.models.project_file_public_file.ProjectFilePublic_file(
                                description = '', 
                                mime_type = 'image/jpeg', 
                                public_url = '', 
                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            description = '', 
                            metadata = keplar_api.models.project_file_metadata.ProjectFileMetadata(
                                name = '', 
                                prompt = '', 
                                image_description = '', ), )
                        ], 
                    language = 'en', 
                    video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                        enabled = True, 
                        include_audio = True, ), ),
        )
        """

    def testJoinCodeInvite302Response(self):
        """Test JoinCodeInvite302Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Participant(BaseModel):
    """
    Participant
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    email: Optional[StrictStr] = None
    phone_number: Optional[StrictStr] = Field(default=None, alias="phoneNumber")
    name: Optional[StrictStr] = None
    data: Optional[Dict[str, Any]] = None
    workspace_id: StrictStr = Field(alias="workspaceId")
    workspace: Optional[Workspace] = None
    participant_invites: Optional[List[ParticipantInvite]] = Field(default=None, alias="participantInvites")
    invite_responses: Optional[List[InviteResponse]] = Field(default=None, alias="inviteResponses")
    calls: Optional[List[Call]] = None
    participant_attributes: Optional[List[ParticipantAttribute]] = Field(default=None, alias="participantAttributes")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "email", "phoneNumber", "name", "data", "workspaceId", "workspace", "participantInvites", "inviteResponses", "calls", "participantAttributes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Participant from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of workspace
        if self.workspace:
            _dict['workspace'] = self.workspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in participant_invites (list)
        _items = []
        if self.participant_invites:
            for _item_participant_invites in self.participant_invites:
                if _item_participant_invites:
                    _items.append(_item_participant_invites.to_dict())
            _dict['participantInvites'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invite_responses (list)
        _items = []
        if self.invite_responses:
            for _item_invite_responses in self.invite_responses:
                if _item_invite_responses:
                    _items.append(_item_invite_responses.to_dict())
            _dict['inviteResponses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in calls (list)
        _items = []
        if self.calls:
            for _item_calls in self.calls:
                if _item_calls:
                    _items.append(_item_calls.to_dict())
            _dict['calls'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in participant_attributes (list)
        _items = []
        if self.participant_attributes:
            for _item_participant_attributes in self.participant_attributes:
                if _item_participant_attributes:
                    _items.append(_item_participant_attributes.to_dict())
            _dict['participantAttributes'] = _items
        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phoneNumber'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Participant from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "email": obj.get("email"),
            "phoneNumber": obj.get("phoneNumber"),
            "name": obj.get("name"),
            "data": obj.get("data"),
            "workspaceId": obj.get("workspaceId"),
            "workspace": Workspace.from_dict(obj["workspace"]) if obj.get("workspace") is not None else None,
            "participantInvites": [ParticipantInvite.from_dict(_item) for _item in obj["participantInvites"]] if obj.get("participantInvites") is not None else None,
            "inviteResponses": [InviteResponse.from_dict(_item) for _item in obj["inviteResponses"]] if obj.get("inviteResponses") is not None else None,
            "calls": [Call.from_dict(_item) for _item in obj["calls"]] if obj.get("calls") is not None else None,
            "participantAttributes": [ParticipantAttribute.from_dict(_item) for _item in obj["participantAttributes"]] if obj.get("participantAttributes") is not None else None
        })
        return _obj

from keplar_api.models.call import Call
from keplar_api.models.invite_response import InviteResponse
from keplar_api.models.participant_attribute import ParticipantAttribute
from keplar_api.models.participant_invite import ParticipantInvite
from keplar_api.models.workspace import Workspace
# TODO: Rewrite to not use raise_errors
Participant.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.repdata_survey import RepdataSurvey

class TestRepdataSurvey(unittest.TestCase):
    """RepdataSurvey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepdataSurvey:
        """Test RepdataSurvey
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepdataSurvey`
        """
        model = RepdataSurvey()
        if include_optional:
            return RepdataSurvey(
                id = '',
                project_id = '',
                name = '',
                status = '',
                survey_attributes = keplar_api.models.repdata_survey_attributes.RepdataSurveyAttributes(
                    respondents = 1.337, 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    minimum_price_per_complete = 1.337, 
                    offered_price_per_complete = 1.337, 
                    device_compatibilities = [
                        ''
                        ], 
                    collects_pii = True, 
                    hashing_enabled = True, 
                    calculation_type = '', 
                    traffic_control_limit_type = '', 
                    out_of_field_date = '', 
                    out_of_field_timezone = '', 
                    entry_link = '', 
                    redirects = keplar_api.models.repdata_survey_redirects.RepdataSurveyRedirects(
                        complete = '', 
                        standard_termination = '', 
                        quality_termination = '', 
                        security_termination = '', 
                        overquota_termination_term = '', ), ),
                respondent_attributes = [
                    keplar_api.models.repdata_respondent_attribute.RepdataRespondentAttribute(
                        quota_id = '', 
                        quota_name = '', 
                        quota = 1.337, 
                        survey_starts = 1.337, 
                        survey_completes = 1.337, 
                        qualifications = [
                            keplar_api.models.repdata_qualification.RepdataQualification(
                                question_id = 1.337, 
                                allowed_option_ids = [
                                    null
                                    ], )
                            ], )
                    ]
            )
        else:
            return RepdataSurvey(
                id = '',
                project_id = '',
                name = '',
                status = '',
                survey_attributes = keplar_api.models.repdata_survey_attributes.RepdataSurveyAttributes(
                    respondents = 1.337, 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    minimum_price_per_complete = 1.337, 
                    offered_price_per_complete = 1.337, 
                    device_compatibilities = [
                        ''
                        ], 
                    collects_pii = True, 
                    hashing_enabled = True, 
                    calculation_type = '', 
                    traffic_control_limit_type = '', 
                    out_of_field_date = '', 
                    out_of_field_timezone = '', 
                    entry_link = '', 
                    redirects = keplar_api.models.repdata_survey_redirects.RepdataSurveyRedirects(
                        complete = '', 
                        standard_termination = '', 
                        quality_termination = '', 
                        security_termination = '', 
                        overquota_termination_term = '', ), ),
                respondent_attributes = [
                    keplar_api.models.repdata_respondent_attribute.RepdataRespondentAttribute(
                        quota_id = '', 
                        quota_name = '', 
                        quota = 1.337, 
                        survey_starts = 1.337, 
                        survey_completes = 1.337, 
                        qualifications = [
                            keplar_api.models.repdata_qualification.RepdataQualification(
                                question_id = 1.337, 
                                allowed_option_ids = [
                                    null
                                    ], )
                            ], )
                    ],
        )
        """

    def testRepdataSurvey(self):
        """Test RepdataSurvey"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.user_search_result import UserSearchResult

class TestUserSearchResult(unittest.TestCase):
    """UserSearchResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserSearchResult:
        """Test UserSearchResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserSearchResult`
        """
        model = UserSearchResult()
        if include_optional:
            return UserSearchResult(
                id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                data = None,
                org_id = '',
                org = keplar_api.models.user_org.UserOrg(
                    id = '', 
                    name = '', ),
                projects = [
                    keplar_api.models.user_project.UserProject(
                        id = '', 
                        name = '', )
                    ],
                default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                    id = '', 
                    name = '', ),
                created_at = ''
            )
        else:
            return UserSearchResult(
                id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                data = None,
                org_id = '',
                org = keplar_api.models.user_org.UserOrg(
                    id = '', 
                    name = '', ),
                projects = [
                    keplar_api.models.user_project.UserProject(
                        id = '', 
                        name = '', )
                    ],
                default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                    id = '', 
                    name = '', ),
                created_at = '',
        )
        """

    def testUserSearchResult(self):
        """Test UserSearchResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner import ArtifactDataSearchResultTabsInnerMessagesInner

class TestArtifactDataSearchResultTabsInnerMessagesInner(unittest.TestCase):
    """ArtifactDataSearchResultTabsInnerMessagesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataSearchResultTabsInnerMessagesInner:
        """Test ArtifactDataSearchResultTabsInnerMessagesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataSearchResultTabsInnerMessagesInner`
        """
        model = ArtifactDataSearchResultTabsInnerMessagesInner()
        if include_optional:
            return ArtifactDataSearchResultTabsInnerMessagesInner(
                call_id = '',
                project_id = '',
                project_name = '',
                recording_url = '',
                message_index = 1.337,
                message = '',
                score = 1.337,
                context_messages = [
                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                        role = '', 
                        message = '', 
                        index = 1.337, 
                        seconds_from_start = 1.337, 
                        duration = 1.337, )
                    ]
            )
        else:
            return ArtifactDataSearchResultTabsInnerMessagesInner(
                call_id = '',
                project_id = '',
                project_name = '',
                message_index = 1.337,
                message = '',
                score = 1.337,
                context_messages = [
                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                        role = '', 
                        message = '', 
                        index = 1.337, 
                        seconds_from_start = 1.337, 
                        duration = 1.337, )
                    ],
        )
        """

    def testArtifactDataSearchResultTabsInnerMessagesInner(self):
        """Test ArtifactDataSearchResultTabsInnerMessagesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.repdata_survey_attributes import RepdataSurveyAttributes

class TestRepdataSurveyAttributes(unittest.TestCase):
    """RepdataSurveyAttributes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepdataSurveyAttributes:
        """Test RepdataSurveyAttributes
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepdataSurveyAttributes`
        """
        model = RepdataSurveyAttributes()
        if include_optional:
            return RepdataSurveyAttributes(
                respondents = 1.337,
                country_code = '',
                language_code = '',
                length_of_interview = 1.337,
                incidence_rate = 1.337,
                minimum_price_per_complete = 1.337,
                offered_price_per_complete = 1.337,
                device_compatibilities = [
                    ''
                    ],
                collects_pii = True,
                hashing_enabled = True,
                calculation_type = '',
                traffic_control_limit_type = '',
                out_of_field_date = '',
                out_of_field_timezone = '',
                entry_link = '',
                redirects = keplar_api.models.repdata_survey_redirects.RepdataSurveyRedirects(
                    complete = '', 
                    standard_termination = '', 
                    quality_termination = '', 
                    security_termination = '', 
                    overquota_termination_term = '', )
            )
        else:
            return RepdataSurveyAttributes(
                respondents = 1.337,
                country_code = '',
                language_code = '',
                length_of_interview = 1.337,
                incidence_rate = 1.337,
                minimum_price_per_complete = 1.337,
                offered_price_per_complete = 1.337,
                device_compatibilities = [
                    ''
                    ],
                collects_pii = True,
                hashing_enabled = True,
                calculation_type = '',
                traffic_control_limit_type = '',
                out_of_field_date = '',
                out_of_field_timezone = '',
                entry_link = '',
                redirects = keplar_api.models.repdata_survey_redirects.RepdataSurveyRedirects(
                    complete = '', 
                    standard_termination = '', 
                    quality_termination = '', 
                    security_termination = '', 
                    overquota_termination_term = '', ),
        )
        """

    def testRepdataSurveyAttributes(self):
        """Test RepdataSurveyAttributes"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_config import ProjectConfig

class TestProjectConfig(unittest.TestCase):
    """ProjectConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectConfig:
        """Test ProjectConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectConfig`
        """
        model = ProjectConfig()
        if include_optional:
            return ProjectConfig(
                project_kind = 'custom',
                prompt_variables = {
                    'key' : null
                    },
                learning_plan = '',
                brief = keplar_api.models.project_brief.ProjectBrief(
                    title = '', 
                    objective = '', 
                    learning_goals = '', 
                    key_questions = '', 
                    conversation_flow = [
                        ''
                        ], 
                    rules = [
                        ''
                        ], 
                    assets = [
                        ''
                        ], ),
                current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                    doc = keplar_api.models.brief_document.BriefDocument(
                        type = 'doc', 
                        content = [
                            keplar_api.models.content_node.ContentNode()
                            ], ), 
                    version = 1.337, 
                    created_at = '', 
                    updated_at = '', ),
                brief_document = '',
                screener_questions = [
                    keplar_api.models.screener_question.ScreenerQuestion()
                    ],
                audience_settings = keplar_api.models.project_audience.ProjectAudience(
                    sample_size = 1.337, 
                    invite_title = '', 
                    invite_description = '', 
                    participants = [
                        keplar_api.models.participant_create.ParticipantCreate(
                            id = '', 
                            name = '', 
                            email = '', 
                            phone_number = '01234', 
                            data = keplar_api.models.data.data(), )
                        ], 
                    panel_settings = keplar_api.models.panel_settings.PanelSettings(
                        respondent_attributes = [
                            keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                qualifications = [
                                    keplar_api.models.panel_qualification.PanelQualification(
                                        allowed_option_ids = [
                                            null
                                            ], 
                                        question_id = 1.337, )
                                    ], 
                                quota = 1.337, 
                                quota_name = '', )
                            ], 
                        country_code = '', 
                        language_code = '', 
                        length_of_interview = 1.337, 
                        incidence_rate = 1.337, 
                        compensation = 1.337, ), 
                    use_public_link = True, )
            )
        else:
            return ProjectConfig(
                prompt_variables = {
                    'key' : null
                    },
                learning_plan = '',
        )
        """

    def testProjectConfig(self):
        """Test ProjectConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.transcript import Transcript

class TestTranscript(unittest.TestCase):
    """Transcript unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Transcript:
        """Test Transcript
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Transcript`
        """
        model = Transcript()
        if include_optional:
            return Transcript(
                id = '',
                response_id = '',
                messages = [
                    keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                        call_id = '', 
                        index = 1.337, 
                        role = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        message = '', )
                    ],
                attributes = [
                    keplar_api.models.transcript_attributes_inner.Transcript_attributes_inner(
                        label = '', 
                        value = '', )
                    ]
            )
        else:
            return Transcript(
                id = '',
                response_id = '',
                messages = [
                    keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                        call_id = '', 
                        index = 1.337, 
                        role = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        message = '', )
                    ],
        )
        """

    def testTranscript(self):
        """Test Transcript"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.api.default_api import DefaultApi


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_user_to_workspace(self) -> None:
        """Test case for add_user_to_workspace

        Add user to a workspace
        """
        pass

    async def test_add_workspace_member(self) -> None:
        """Test case for add_workspace_member

        Add workspace member
        """
        pass

    async def test_analyze_notebook(self) -> None:
        """Test case for analyze_notebook

        Trigger analysis/report generation for a notebook
        """
        pass

    async def test_api_auth_google_get(self) -> None:
        """Test case for api_auth_google_get

        """
        pass

    async def test_api_auth_google_redirect_get(self) -> None:
        """Test case for api_auth_google_redirect_get

        """
        pass

    async def test_api_call_messages_search_post(self) -> None:
        """Test case for api_call_messages_search_post

        Search conversation messages
        """
        pass

    async def test_api_calls_call_id_get(self) -> None:
        """Test case for api_calls_call_id_get

        Get call
        """
        pass

    async def test_api_calls_call_id_messages_index_get(self) -> None:
        """Test case for api_calls_call_id_messages_index_get

        Get conversation message
        """
        pass

    async def test_api_copilotkit_post(self) -> None:
        """Test case for api_copilotkit_post

        """
        pass

    async def test_api_demos_create_demo_invite_post(self) -> None:
        """Test case for api_demos_create_demo_invite_post

        Create demo invite
        """
        pass

    async def test_api_files_file_id_delete(self) -> None:
        """Test case for api_files_file_id_delete

        Delete a file
        """
        pass

    async def test_api_files_file_id_get(self) -> None:
        """Test case for api_files_file_id_get

        Get file metadata
        """
        pass

    async def test_api_files_file_id_signed_url_post(self) -> None:
        """Test case for api_files_file_id_signed_url_post

        Get a signed URL for file access
        """
        pass

    async def test_api_files_post(self) -> None:
        """Test case for api_files_post

        Upload a file
        """
        pass

    async def test_api_invite_code_code_participant_code_participant_code_join_get(self) -> None:
        """Test case for api_invite_code_code_participant_code_participant_code_join_get

        """
        pass

    async def test_api_invite_code_code_start_get(self) -> None:
        """Test case for api_invite_code_code_start_get

        """
        pass

    async def test_api_invites_id_get(self) -> None:
        """Test case for api_invites_id_get

        Get invite
        """
        pass

    async def test_api_invites_id_participant_invites_get(self) -> None:
        """Test case for api_invites_id_participant_invites_get

        Get participant invites
        """
        pass

    async def test_api_invites_id_participant_invites_participant_id_get(self) -> None:
        """Test case for api_invites_id_participant_invites_participant_id_get

        Get participant invite
        """
        pass

    async def test_api_invites_id_participant_invites_participant_id_put(self) -> None:
        """Test case for api_invites_id_participant_invites_participant_id_put

        Update participant invite
        """
        pass

    async def test_api_invites_id_participant_invites_post(self) -> None:
        """Test case for api_invites_id_participant_invites_post

        Create participant invite
        """
        pass

    async def test_api_invites_id_participants_participant_id_call_metadata_get(self) -> None:
        """Test case for api_invites_id_participants_participant_id_call_metadata_get

        Get call metadata by invite ID and participant ID
        """
        pass

    async def test_api_invites_id_put(self) -> None:
        """Test case for api_invites_id_put

        Update invite
        """
        pass

    async def test_api_invites_id_response_attribute_stats_get(self) -> None:
        """Test case for api_invites_id_response_attribute_stats_get

        Get invite response attribute stats
        """
        pass

    async def test_api_invites_id_responses_get(self) -> None:
        """Test case for api_invites_id_responses_get

        Get invite responses
        """
        pass

    async def test_api_invites_id_responses_post(self) -> None:
        """Test case for api_invites_id_responses_post

        Create invite response
        """
        pass

    async def test_api_invites_id_responses_response_id_call_metadata_get(self) -> None:
        """Test case for api_invites_id_responses_response_id_call_metadata_get

        Get call metadata by invite ID and response ID
        """
        pass

    async def test_api_invites_id_responses_response_id_get(self) -> None:
        """Test case for api_invites_id_responses_response_id_get

        Get invite response
        """
        pass

    async def test_api_invites_id_responses_response_id_put(self) -> None:
        """Test case for api_invites_id_responses_response_id_put

        Update invite response
        """
        pass

    async def test_api_invites_post(self) -> None:
        """Test case for api_invites_post

        Create invite
        """
        pass

    async def test_api_projects_draft_get(self) -> None:
        """Test case for api_projects_draft_get

        Get draft project
        """
        pass

    async def test_api_projects_post(self) -> None:
        """Test case for api_projects_post

        Create project
        """
        pass

    async def test_api_projects_project_id_analysis_post(self) -> None:
        """Test case for api_projects_project_id_analysis_post

        Create project analysis
        """
        pass

    async def test_api_projects_project_id_delete_post(self) -> None:
        """Test case for api_projects_project_id_delete_post

        Delete or archive project
        """
        pass

    async def test_api_projects_project_id_files_file_id_delete(self) -> None:
        """Test case for api_projects_project_id_files_file_id_delete

        Remove a file from a project
        """
        pass

    async def test_api_projects_project_id_files_file_id_put(self) -> None:
        """Test case for api_projects_project_id_files_file_id_put

        Update project file metadata
        """
        pass

    async def test_api_projects_project_id_files_get(self) -> None:
        """Test case for api_projects_project_id_files_get

        Get files for a project
        """
        pass

    async def test_api_projects_project_id_files_post(self) -> None:
        """Test case for api_projects_project_id_files_post

        Add an existing file to a project
        """
        pass

    async def test_api_projects_project_id_launch_post(self) -> None:
        """Test case for api_projects_project_id_launch_post

        Launch project
        """
        pass

    async def test_api_projects_project_id_put(self) -> None:
        """Test case for api_projects_project_id_put

        Update project
        """
        pass

    async def test_api_projects_project_id_search_transcripts_post(self) -> None:
        """Test case for api_projects_project_id_search_transcripts_post

        Search project transcripts
        """
        pass

    async def test_api_threads_get(self) -> None:
        """Test case for api_threads_get

        Get threads
        """
        pass

    async def test_api_threads_thread_id_files_get(self) -> None:
        """Test case for api_threads_thread_id_files_get

        Get thread files
        """
        pass

    async def test_api_threads_thread_id_post(self) -> None:
        """Test case for api_threads_thread_id_post

        Upsert thread
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_get(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_get

        Get project brief document versions from thread state history
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_post(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_post

        Create project brief document version from thread state
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_version_put(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_version_put

        Update a specific project brief document version
        """
        pass

    async def test_api_threads_thread_id_project_brief_versions_get(self) -> None:
        """Test case for api_threads_thread_id_project_brief_versions_get

        Get project brief versions from thread state history
        """
        pass

    async def test_api_threads_thread_id_project_brief_versions_post(self) -> None:
        """Test case for api_threads_thread_id_project_brief_versions_post

        Create project draft versions from thread state history
        """
        pass

    async def test_api_users_id_get(self) -> None:
        """Test case for api_users_id_get

        Get user with configuration
        """
        pass

    async def test_api_vapi_webhook_post(self) -> None:
        """Test case for api_vapi_webhook_post

        """
        pass

    async def test_create_artifact(self) -> None:
        """Test case for create_artifact

        Create artifact
        """
        pass

    async def test_create_code_invite_response(self) -> None:
        """Test case for create_code_invite_response

        Create invite response for invite code
        """
        pass

    async def test_create_code_invite_response_from_existing(self) -> None:
        """Test case for create_code_invite_response_from_existing

        Create invite response from existing response
        """
        pass

    async def test_create_dummy_user(self) -> None:
        """Test case for create_dummy_user

        Create a dummy user for sales demos
        """
        pass

    async def test_create_email_share(self) -> None:
        """Test case for create_email_share

        Add email access to a share
        """
        pass

    async def test_create_notebook(self) -> None:
        """Test case for create_notebook

        Create a new notebook
        """
        pass

    async def test_create_notebook_artifact(self) -> None:
        """Test case for create_notebook_artifact

        Create an empty artifact for a notebook
        """
        pass

    async def test_create_org(self) -> None:
        """Test case for create_org

        Create a new organization
        """
        pass

    async def test_create_project_preview_invite(self) -> None:
        """Test case for create_project_preview_invite

        Create a preview invite for this project based on audienceSettings
        """
        pass

    async def test_create_project_share(self) -> None:
        """Test case for create_project_share

        Create a share link for a project
        """
        pass

    async def test_create_test_participant_code_invite(self) -> None:
        """Test case for create_test_participant_code_invite

        Create test invite for participant
        """
        pass

    async def test_create_transcript_insight_for_code_invite_response(self) -> None:
        """Test case for create_transcript_insight_for_code_invite_response

        Create transcript insight for invite response
        """
        pass

    async def test_create_workspace(self) -> None:
        """Test case for create_workspace

        Create workspace
        """
        pass

    async def test_delete_artifact(self) -> None:
        """Test case for delete_artifact

        Delete artifact
        """
        pass

    async def test_delete_email_share(self) -> None:
        """Test case for delete_email_share

        Remove email access from a share
        """
        pass

    async def test_delete_notebook(self) -> None:
        """Test case for delete_notebook

        Delete a notebook
        """
        pass

    async def test_delete_notebook_artifact_version_group(self) -> None:
        """Test case for delete_notebook_artifact_version_group

        Delete all artifacts in a version group
        """
        pass

    async def test_delete_project_search_index(self) -> None:
        """Test case for delete_project_search_index

        Delete project search index from Qdrant
        """
        pass

    async def test_delete_share_entity(self) -> None:
        """Test case for delete_share_entity

        Delete a share entity
        """
        pass

    async def test_download_invite_responses(self) -> None:
        """Test case for download_invite_responses

        Download invite responses as CSV
        """
        pass

    async def test_download_share_invite_responses(self) -> None:
        """Test case for download_share_invite_responses

        Download invite responses as CSV
        """
        pass

    async def test_generate_presentation_artifact(self) -> None:
        """Test case for generate_presentation_artifact

        Generate presentation via Gamma API for a presentation artifact
        """
        pass

    async def test_get_artifact(self) -> None:
        """Test case for get_artifact

        Get artifact by ID
        """
        pass

    async def test_get_artifact_version_groups(self) -> None:
        """Test case for get_artifact_version_groups

        Get project artifact version groups
        """
        pass

    async def test_get_call_metadata_for_code_invite_response(self) -> None:
        """Test case for get_call_metadata_for_code_invite_response

        Get call metadata for invite response
        """
        pass

    async def test_get_code_invite(self) -> None:
        """Test case for get_code_invite

        Get invite by code
        """
        pass

    async def test_get_code_invite_participant_remaining_responses(self) -> None:
        """Test case for get_code_invite_participant_remaining_responses

        Get remaining responses count for participant
        """
        pass

    async def test_get_code_invite_participant_response(self) -> None:
        """Test case for get_code_invite_participant_response

        Get invite response for participant
        """
        pass

    async def test_get_code_invite_response(self) -> None:
        """Test case for get_code_invite_response

        Get invite response
        """
        pass

    async def test_get_code_invite_response_redirect(self) -> None:
        """Test case for get_code_invite_response_redirect

        Get redirect URL for invite response
        """
        pass

    async def test_get_code_participant_invite(self) -> None:
        """Test case for get_code_participant_invite

        Get participant invite for invite code
        """
        pass

    async def test_get_notebook(self) -> None:
        """Test case for get_notebook

        Get a notebook by ID
        """
        pass

    async def test_get_notebook_artifacts(self) -> None:
        """Test case for get_notebook_artifacts

        Get all artifacts generated from a notebook
        """
        pass

    async def test_get_notebook_projects(self) -> None:
        """Test case for get_notebook_projects

        Get all projects associated with a notebook
        """
        pass

    async def test_get_notebooks(self) -> None:
        """Test case for get_notebooks

        Get all notebooks accessible to user
        """
        pass

    async def test_get_org(self) -> None:
        """Test case for get_org

        Get organization details
        """
        pass

    async def test_get_org_members(self) -> None:
        """Test case for get_org_members

        Get organization members
        """
        pass

    async def test_get_orgs(self) -> None:
        """Test case for get_orgs

        List organizations with stats
        """
        pass

    async def test_get_project(self) -> None:
        """Test case for get_project

        Get project
        """
        pass

    async def test_get_project_artifact(self) -> None:
        """Test case for get_project_artifact

        Get project artifact by ID
        """
        pass

    async def test_get_project_response_attribute_stats(self) -> None:
        """Test case for get_project_response_attribute_stats

        Get project response attribute stats
        """
        pass

    async def test_get_project_responses_metadata(self) -> None:
        """Test case for get_project_responses_metadata

        Get project responses metadata
        """
        pass

    async def test_get_project_shares(self) -> None:
        """Test case for get_project_shares

        Get all shares for a project
        """
        pass

    async def test_get_projects(self) -> None:
        """Test case for get_projects

        Get projects
        """
        pass

    async def test_get_share_entities(self) -> None:
        """Test case for get_share_entities

        List all share entities created by the user
        """
        pass

    async def test_get_shared_artifact(self) -> None:
        """Test case for get_shared_artifact

        Get shared artifact by ID
        """
        pass

    async def test_get_shared_artifact_version_groups(self) -> None:
        """Test case for get_shared_artifact_version_groups

        Get shared project artifacts version groups
        """
        pass

    async def test_get_shared_call(self) -> None:
        """Test case for get_shared_call

        Get shared call data with conversation messages
        """
        pass

    async def test_get_shared_call_metadata(self) -> None:
        """Test case for get_shared_call_metadata

        Get shared call metadata by invite ID and response ID
        """
        pass

    async def test_get_shared_invite_response(self) -> None:
        """Test case for get_shared_invite_response

        Get a single response by ID for a shared invite
        """
        pass

    async def test_get_shared_invite_response_attribute_stats(self) -> None:
        """Test case for get_shared_invite_response_attribute_stats

        Get attribute stats for shared invite responses
        """
        pass

    async def test_get_shared_invite_responses(self) -> None:
        """Test case for get_shared_invite_responses

        Get responses for a shared invite
        """
        pass

    async def test_get_shared_project(self) -> None:
        """Test case for get_shared_project

        Get shared project data
        """
        pass

    async def test_get_shared_project_response_attribute_stats(self) -> None:
        """Test case for get_shared_project_response_attribute_stats

        Get shared project response attribute stats
        """
        pass

    async def test_get_shared_project_responses_metadata(self) -> None:
        """Test case for get_shared_project_responses_metadata

        Get shared project responses metadata
        """
        pass

    async def test_get_user_workspaces(self) -> None:
        """Test case for get_user_workspaces

        Get user workspaces and all available workspaces
        """
        pass

    async def test_get_workspace_members(self) -> None:
        """Test case for get_workspace_members

        Get workspace members
        """
        pass

    async def test_get_workspaces(self) -> None:
        """Test case for get_workspaces

        Get all workspaces
        """
        pass

    async def test_impersonate_user(self) -> None:
        """Test case for impersonate_user

        Impersonate a user
        """
        pass

    async def test_index_project_transcripts(self) -> None:
        """Test case for index_project_transcripts

        Index project transcripts into Qdrant for semantic search
        """
        pass

    async def test_invite_customers(self) -> None:
        """Test case for invite_customers

        Bulk invite customers - creates org/workspace if needed
        """
        pass

    async def test_invite_user(self) -> None:
        """Test case for invite_user

        Send invite to transfer dummy user to customer
        """
        pass

    async def test_join_code_invite(self) -> None:
        """Test case for join_code_invite

        Join invite by code
        """
        pass

    async def test_join_participant_code_invite(self) -> None:
        """Test case for join_participant_code_invite

        Join invite by code and participant code
        """
        pass

    async def test_login(self) -> None:
        """Test case for login

        Login with email and password
        """
        pass

    async def test_logout(self) -> None:
        """Test case for logout

        Logout user
        """
        pass

    async def test_remove_user_from_workspace(self) -> None:
        """Test case for remove_user_from_workspace

        Remove user from a workspace
        """
        pass

    async def test_remove_workspace_member(self) -> None:
        """Test case for remove_workspace_member

        Remove workspace member
        """
        pass

    async def test_request_magic_link(self) -> None:
        """Test case for request_magic_link

        Request magic link for passwordless login
        """
        pass

    async def test_request_password_reset(self) -> None:
        """Test case for request_password_reset

        Request password reset email
        """
        pass

    async def test_request_share_access(self) -> None:
        """Test case for request_share_access

        Request access to a share by email
        """
        pass

    async def test_resend_verification(self) -> None:
        """Test case for resend_verification

        Resend email verification
        """
        pass

    async def test_reset_password(self) -> None:
        """Test case for reset_password

        Reset password with token
        """
        pass

    async def test_save_search(self) -> None:
        """Test case for save_search

        Save search results as a new artifact
        """
        pass

    async def test_search_response_messages(self) -> None:
        """Test case for search_response_messages

        Search response messages by inviteResponseId and messageIndex
        """
        pass

    async def test_search_shared_response_messages(self) -> None:
        """Test case for search_shared_response_messages

        Search shared response messages by responseId and messageIndex
        """
        pass

    async def test_search_users(self) -> None:
        """Test case for search_users

        Search users by email or name
        """
        pass

    async def test_send_user_password_reset(self) -> None:
        """Test case for send_user_password_reset

        Send password reset email to user (admin-triggered)
        """
        pass

    async def test_signup(self) -> None:
        """Test case for signup

        Sign up with email and password
        """
        pass

    async def test_start_call_for_code_invite_response(self) -> None:
        """Test case for start_call_for_code_invite_response

        Start call for invite response
        """
        pass

    async def test_start_phone_call_for_code_invite_response(self) -> None:
        """Test case for start_phone_call_for_code_invite_response

        Start phone call for invite response
        """
        pass

    async def test_update_artifact(self) -> None:
        """Test case for update_artifact

        Update artifact
        """
        pass

    async def test_update_call_for_code_invite_response(self) -> None:
        """Test case for update_call_for_code_invite_response

        Update call for invite response
        """
        pass

    async def test_update_code_invite_response(self) -> None:
        """Test case for update_code_invite_response

        Update invite response
        """
        pass

    async def test_update_notebook(self) -> None:
        """Test case for update_notebook

        Update a notebook
        """
        pass

    async def test_update_notebook_sources(self) -> None:
        """Test case for update_notebook_sources

        Add or remove project sources from a notebook
        """
        pass

    async def test_update_org(self) -> None:
        """Test case for update_org

        Update organization name
        """
        pass

    async def test_update_org2_fa(self) -> None:
        """Test case for update_org2_fa

        Toggle 2FA for organization
        """
        pass

    async def test_update_org_default_workspace(self) -> None:
        """Test case for update_org_default_workspace

        Set/update organization default workspace
        """
        pass

    async def test_update_search(self) -> None:
        """Test case for update_search

        Update existing search artifact
        """
        pass

    async def test_update_share_entity(self) -> None:
        """Test case for update_share_entity

        Update a share entity
        """
        pass

    async def test_update_user_default_workspace(self) -> None:
        """Test case for update_user_default_workspace

        Update user default workspace (auto-adds user if not member)
        """
        pass

    async def test_update_workspace_member(self) -> None:
        """Test case for update_workspace_member

        Update workspace member
        """
        pass

    async def test_upload_call_video(self) -> None:
        """Test case for upload_call_video

        Upload video recording for a call
        """
        pass

    async def test_verify_email(self) -> None:
        """Test case for verify_email

        Verify email address with token
        """
        pass

    async def test_verify_email_access_for_share(self) -> None:
        """Test case for verify_email_access_for_share

        Verify email access for a share
        """
        pass

    async def test_verify_magic_link(self) -> None:
        """Test case for verify_magic_link

        Verify magic link token
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_user_default_workspace200_response import UpdateUserDefaultWorkspace200Response

class TestUpdateUserDefaultWorkspace200Response(unittest.TestCase):
    """UpdateUserDefaultWorkspace200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateUserDefaultWorkspace200Response:
        """Test UpdateUserDefaultWorkspace200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateUserDefaultWorkspace200Response`
        """
        model = UpdateUserDefaultWorkspace200Response()
        if include_optional:
            return UpdateUserDefaultWorkspace200Response(
                success = True,
                default_workspace_id = '',
                was_added_to_workspace = True
            )
        else:
            return UpdateUserDefaultWorkspace200Response(
                success = True,
                default_workspace_id = '',
                was_added_to_workspace = True,
        )
        """

    def testUpdateUserDefaultWorkspace200Response(self):
        """Test UpdateUserDefaultWorkspace200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.panel_settings import PanelSettings

class TestPanelSettings(unittest.TestCase):
    """PanelSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PanelSettings:
        """Test PanelSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PanelSettings`
        """
        model = PanelSettings()
        if include_optional:
            return PanelSettings(
                respondent_attributes = [
                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                        qualifications = [
                            keplar_api.models.panel_qualification.PanelQualification(
                                allowed_option_ids = [
                                    null
                                    ], 
                                question_id = 1.337, )
                            ], 
                        quota = 1.337, 
                        quota_name = '', )
                    ],
                country_code = '',
                language_code = '',
                length_of_interview = 1.337,
                incidence_rate = 1.337,
                compensation = 1.337
            )
        else:
            return PanelSettings(
                respondent_attributes = [
                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                        qualifications = [
                            keplar_api.models.panel_qualification.PanelQualification(
                                allowed_option_ids = [
                                    null
                                    ], 
                                question_id = 1.337, )
                            ], 
                        quota = 1.337, 
                        quota_name = '', )
                    ],
        )
        """

    def testPanelSettings(self):
        """Test PanelSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from keplar_api.models.response_call_completed_event import ResponseCallCompletedEvent
from keplar_api.models.response_call_failed_event import ResponseCallFailedEvent
from keplar_api.models.response_consent_event import ResponseConsentEvent
from keplar_api.models.response_opt_out_event import ResponseOptOutEvent
from keplar_api.models.response_processing_completed_event import ResponseProcessingCompletedEvent
from keplar_api.models.response_processing_failed_event import ResponseProcessingFailedEvent
from keplar_api.models.response_redirect_event import ResponseRedirectEvent
from keplar_api.models.response_start_call_event import ResponseStartCallEvent
from keplar_api.models.response_submit_email_event import ResponseSubmitEmailEvent
from keplar_api.models.response_submit_screener_event import ResponseSubmitScreenerEvent
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

INVITERESPONSEUPDATEEVENT_ONE_OF_SCHEMAS = ["ResponseCallCompletedEvent", "ResponseCallFailedEvent", "ResponseConsentEvent", "ResponseOptOutEvent", "ResponseProcessingCompletedEvent", "ResponseProcessingFailedEvent", "ResponseRedirectEvent", "ResponseStartCallEvent", "ResponseSubmitEmailEvent", "ResponseSubmitScreenerEvent"]

class InviteResponseUpdateEvent(BaseModel):
    """
    InviteResponseUpdateEvent
    """
    # data type: ResponseSubmitEmailEvent
    oneof_schema_1_validator: Optional[ResponseSubmitEmailEvent] = None
    # data type: ResponseSubmitScreenerEvent
    oneof_schema_2_validator: Optional[ResponseSubmitScreenerEvent] = None
    # data type: ResponseOptOutEvent
    oneof_schema_3_validator: Optional[ResponseOptOutEvent] = None
    # data type: ResponseConsentEvent
    oneof_schema_4_validator: Optional[ResponseConsentEvent] = None
    # data type: ResponseStartCallEvent
    oneof_schema_5_validator: Optional[ResponseStartCallEvent] = None
    # data type: ResponseCallCompletedEvent
    oneof_schema_6_validator: Optional[ResponseCallCompletedEvent] = None
    # data type: ResponseCallFailedEvent
    oneof_schema_7_validator: Optional[ResponseCallFailedEvent] = None
    # data type: ResponseProcessingCompletedEvent
    oneof_schema_8_validator: Optional[ResponseProcessingCompletedEvent] = None
    # data type: ResponseProcessingFailedEvent
    oneof_schema_9_validator: Optional[ResponseProcessingFailedEvent] = None
    # data type: ResponseRedirectEvent
    oneof_schema_10_validator: Optional[ResponseRedirectEvent] = None
    actual_instance: Optional[Union[ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent]] = None
    one_of_schemas: Set[str] = { "ResponseCallCompletedEvent", "ResponseCallFailedEvent", "ResponseConsentEvent", "ResponseOptOutEvent", "ResponseProcessingCompletedEvent", "ResponseProcessingFailedEvent", "ResponseRedirectEvent", "ResponseStartCallEvent", "ResponseSubmitEmailEvent", "ResponseSubmitScreenerEvent" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = InviteResponseUpdateEvent.model_construct()
        error_messages = []
        match = 0
        # validate data type: ResponseSubmitEmailEvent
        if not isinstance(v, ResponseSubmitEmailEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseSubmitEmailEvent`")
        else:
            match += 1
        # validate data type: ResponseSubmitScreenerEvent
        if not isinstance(v, ResponseSubmitScreenerEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseSubmitScreenerEvent`")
        else:
            match += 1
        # validate data type: ResponseOptOutEvent
        if not isinstance(v, ResponseOptOutEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseOptOutEvent`")
        else:
            match += 1
        # validate data type: ResponseConsentEvent
        if not isinstance(v, ResponseConsentEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseConsentEvent`")
        else:
            match += 1
        # validate data type: ResponseStartCallEvent
        if not isinstance(v, ResponseStartCallEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseStartCallEvent`")
        else:
            match += 1
        # validate data type: ResponseCallCompletedEvent
        if not isinstance(v, ResponseCallCompletedEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseCallCompletedEvent`")
        else:
            match += 1
        # validate data type: ResponseCallFailedEvent
        if not isinstance(v, ResponseCallFailedEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseCallFailedEvent`")
        else:
            match += 1
        # validate data type: ResponseProcessingCompletedEvent
        if not isinstance(v, ResponseProcessingCompletedEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseProcessingCompletedEvent`")
        else:
            match += 1
        # validate data type: ResponseProcessingFailedEvent
        if not isinstance(v, ResponseProcessingFailedEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseProcessingFailedEvent`")
        else:
            match += 1
        # validate data type: ResponseRedirectEvent
        if not isinstance(v, ResponseRedirectEvent):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ResponseRedirectEvent`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in InviteResponseUpdateEvent with oneOf schemas: ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in InviteResponseUpdateEvent with oneOf schemas: ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into ResponseSubmitEmailEvent
        try:
            instance.actual_instance = ResponseSubmitEmailEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseSubmitScreenerEvent
        try:
            instance.actual_instance = ResponseSubmitScreenerEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseOptOutEvent
        try:
            instance.actual_instance = ResponseOptOutEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseConsentEvent
        try:
            instance.actual_instance = ResponseConsentEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseStartCallEvent
        try:
            instance.actual_instance = ResponseStartCallEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseCallCompletedEvent
        try:
            instance.actual_instance = ResponseCallCompletedEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseCallFailedEvent
        try:
            instance.actual_instance = ResponseCallFailedEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseProcessingCompletedEvent
        try:
            instance.actual_instance = ResponseProcessingCompletedEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseProcessingFailedEvent
        try:
            instance.actual_instance = ResponseProcessingFailedEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ResponseRedirectEvent
        try:
            instance.actual_instance = ResponseRedirectEvent.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into InviteResponseUpdateEvent with oneOf schemas: ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into InviteResponseUpdateEvent with oneOf schemas: ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], ResponseCallCompletedEvent, ResponseCallFailedEvent, ResponseConsentEvent, ResponseOptOutEvent, ResponseProcessingCompletedEvent, ResponseProcessingFailedEvent, ResponseRedirectEvent, ResponseStartCallEvent, ResponseSubmitEmailEvent, ResponseSubmitScreenerEvent]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.attribute_value_kind import AttributeValueKind
from typing import Optional, Set
from typing_extensions import Self

class AttributeKind(BaseModel):
    """
    AttributeKind
    """ # noqa: E501
    id: StrictStr
    key: Optional[StrictStr] = None
    label: StrictStr
    value_kind: AttributeValueKind = Field(alias="valueKind")
    description: Optional[StrictStr] = None
    category: Optional[StrictStr] = None
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    attribute_kind_group_id: Optional[StrictStr] = Field(default=None, alias="attributeKindGroupId")
    attributes: Optional[List[Attribute]] = None
    attribute_kind_group: Optional[AttributeKindGroup] = Field(default=None, alias="attributeKindGroup")
    __properties: ClassVar[List[str]] = ["id", "key", "label", "valueKind", "description", "category", "createdAt", "updatedAt", "attributeKindGroupId", "attributes", "attributeKindGroup"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AttributeKind from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attributes (list)
        _items = []
        if self.attributes:
            for _item_attributes in self.attributes:
                if _item_attributes:
                    _items.append(_item_attributes.to_dict())
            _dict['attributes'] = _items
        # override the default output from pydantic by calling `to_dict()` of attribute_kind_group
        if self.attribute_kind_group:
            _dict['attributeKindGroup'] = self.attribute_kind_group.to_dict()
        # set to None if key (nullable) is None
        # and model_fields_set contains the field
        if self.key is None and "key" in self.model_fields_set:
            _dict['key'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if category (nullable) is None
        # and model_fields_set contains the field
        if self.category is None and "category" in self.model_fields_set:
            _dict['category'] = None

        # set to None if attribute_kind_group_id (nullable) is None
        # and model_fields_set contains the field
        if self.attribute_kind_group_id is None and "attribute_kind_group_id" in self.model_fields_set:
            _dict['attributeKindGroupId'] = None

        # set to None if attribute_kind_group (nullable) is None
        # and model_fields_set contains the field
        if self.attribute_kind_group is None and "attribute_kind_group" in self.model_fields_set:
            _dict['attributeKindGroup'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AttributeKind from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "key": obj.get("key"),
            "label": obj.get("label"),
            "valueKind": obj.get("valueKind"),
            "description": obj.get("description"),
            "category": obj.get("category"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "attributeKindGroupId": obj.get("attributeKindGroupId"),
            "attributes": [Attribute.from_dict(_item) for _item in obj["attributes"]] if obj.get("attributes") is not None else None,
            "attributeKindGroup": AttributeKindGroup.from_dict(obj["attributeKindGroup"]) if obj.get("attributeKindGroup") is not None else None
        })
        return _obj

from keplar_api.models.attribute import Attribute
from keplar_api.models.attribute_kind_group import AttributeKindGroup
# TODO: Rewrite to not use raise_errors
AttributeKind.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.artifact_kind import ArtifactKind
from typing import Optional, Set
from typing_extensions import Self

class ArtifactVersionGroup(BaseModel):
    """
    ArtifactVersionGroup
    """ # noqa: E501
    id: StrictStr
    project_id: Optional[StrictStr] = Field(default=None, alias="projectId")
    kind: ArtifactKind
    latest_artifact_id: Optional[StrictStr] = Field(default=None, alias="latestArtifactId")
    project: Optional[Project] = None
    latest_artifact: Optional[Artifact] = Field(default=None, alias="latestArtifact")
    artifacts: Optional[List[Artifact]] = None
    notebook_artifact_version_groups: Optional[List[NotebookArtifactVersionGroup]] = Field(default=None, alias="notebookArtifactVersionGroups")
    __properties: ClassVar[List[str]] = ["id", "projectId", "kind", "latestArtifactId", "project", "latestArtifact", "artifacts", "notebookArtifactVersionGroups"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ArtifactVersionGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_artifact
        if self.latest_artifact:
            _dict['latestArtifact'] = self.latest_artifact.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in artifacts (list)
        _items = []
        if self.artifacts:
            for _item_artifacts in self.artifacts:
                if _item_artifacts:
                    _items.append(_item_artifacts.to_dict())
            _dict['artifacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in notebook_artifact_version_groups (list)
        _items = []
        if self.notebook_artifact_version_groups:
            for _item_notebook_artifact_version_groups in self.notebook_artifact_version_groups:
                if _item_notebook_artifact_version_groups:
                    _items.append(_item_notebook_artifact_version_groups.to_dict())
            _dict['notebookArtifactVersionGroups'] = _items
        # set to None if project_id (nullable) is None
        # and model_fields_set contains the field
        if self.project_id is None and "project_id" in self.model_fields_set:
            _dict['projectId'] = None

        # set to None if latest_artifact_id (nullable) is None
        # and model_fields_set contains the field
        if self.latest_artifact_id is None and "latest_artifact_id" in self.model_fields_set:
            _dict['latestArtifactId'] = None

        # set to None if project (nullable) is None
        # and model_fields_set contains the field
        if self.project is None and "project" in self.model_fields_set:
            _dict['project'] = None

        # set to None if latest_artifact (nullable) is None
        # and model_fields_set contains the field
        if self.latest_artifact is None and "latest_artifact" in self.model_fields_set:
            _dict['latestArtifact'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ArtifactVersionGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "projectId": obj.get("projectId"),
            "kind": obj.get("kind"),
            "latestArtifactId": obj.get("latestArtifactId"),
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "latestArtifact": Artifact.from_dict(obj["latestArtifact"]) if obj.get("latestArtifact") is not None else None,
            "artifacts": [Artifact.from_dict(_item) for _item in obj["artifacts"]] if obj.get("artifacts") is not None else None,
            "notebookArtifactVersionGroups": [NotebookArtifactVersionGroup.from_dict(_item) for _item in obj["notebookArtifactVersionGroups"]] if obj.get("notebookArtifactVersionGroups") is not None else None
        })
        return _obj

from keplar_api.models.artifact import Artifact
from keplar_api.models.notebook_artifact_version_group import NotebookArtifactVersionGroup
from keplar_api.models.project import Project
# TODO: Rewrite to not use raise_errors
ArtifactVersionGroup.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.call_analysis import CallAnalysis
from typing import Optional, Set
from typing_extensions import Self

class CallMetadata(BaseModel):
    """
    CallMetadata
    """ # noqa: E501
    recording_url: Optional[StrictStr] = Field(default=None, alias="recordingUrl")
    transcript: Optional[StrictStr] = None
    transcript_quality: Optional[StrictStr] = Field(default=None, alias="transcriptQuality")
    transcript_markdown: Optional[StrictStr] = Field(default=None, alias="transcriptMarkdown")
    transcript_insight: Optional[StrictStr] = Field(default=None, alias="transcriptInsight")
    analysis: Optional[CallAnalysis] = None
    gcs_url: Optional[StrictStr] = Field(default=None, alias="gcsUrl")
    gcs_path: Optional[StrictStr] = Field(default=None, alias="gcsPath")
    gcs_uploaded_at: Optional[StrictStr] = Field(default=None, alias="gcsUploadedAt")
    gcs_last_synced_at: Optional[StrictStr] = Field(default=None, alias="gcsLastSyncedAt")
    video_recording_url: Optional[StrictStr] = Field(default=None, alias="videoRecordingUrl")
    video_gcs_url: Optional[StrictStr] = Field(default=None, alias="videoGcsUrl")
    video_gcs_path: Optional[StrictStr] = Field(default=None, alias="videoGcsPath")
    video_uploaded_at: Optional[StrictStr] = Field(default=None, alias="videoUploadedAt")
    video_mime_type: Optional[StrictStr] = Field(default=None, alias="videoMimeType")
    video_duration_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="videoDurationSeconds")
    video_size_bytes: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="videoSizeBytes")
    video_recording_status: Optional[StrictStr] = Field(default=None, alias="videoRecordingStatus")
    video_recording_error: Optional[StrictStr] = Field(default=None, alias="videoRecordingError")
    __properties: ClassVar[List[str]] = ["recordingUrl", "transcript", "transcriptQuality", "transcriptMarkdown", "transcriptInsight", "analysis", "gcsUrl", "gcsPath", "gcsUploadedAt", "gcsLastSyncedAt", "videoRecordingUrl", "videoGcsUrl", "videoGcsPath", "videoUploadedAt", "videoMimeType", "videoDurationSeconds", "videoSizeBytes", "videoRecordingStatus", "videoRecordingError"]

    @field_validator('transcript_quality')
    def transcript_quality_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['HIGH', 'MEDIUM', 'LOW']):
            raise ValueError("must be one of enum values ('HIGH', 'MEDIUM', 'LOW')")
        return value

    @field_validator('video_recording_status')
    def video_recording_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['recording', 'uploading', 'completed', 'failed', 'skipped']):
            raise ValueError("must be one of enum values ('recording', 'uploading', 'completed', 'failed', 'skipped')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of analysis
        if self.analysis:
            _dict['analysis'] = self.analysis.to_dict()
        # set to None if analysis (nullable) is None
        # and model_fields_set contains the field
        if self.analysis is None and "analysis" in self.model_fields_set:
            _dict['analysis'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "recordingUrl": obj.get("recordingUrl"),
            "transcript": obj.get("transcript"),
            "transcriptQuality": obj.get("transcriptQuality"),
            "transcriptMarkdown": obj.get("transcriptMarkdown"),
            "transcriptInsight": obj.get("transcriptInsight"),
            "analysis": CallAnalysis.from_dict(obj["analysis"]) if obj.get("analysis") is not None else None,
            "gcsUrl": obj.get("gcsUrl"),
            "gcsPath": obj.get("gcsPath"),
            "gcsUploadedAt": obj.get("gcsUploadedAt"),
            "gcsLastSyncedAt": obj.get("gcsLastSyncedAt"),
            "videoRecordingUrl": obj.get("videoRecordingUrl"),
            "videoGcsUrl": obj.get("videoGcsUrl"),
            "videoGcsPath": obj.get("videoGcsPath"),
            "videoUploadedAt": obj.get("videoUploadedAt"),
            "videoMimeType": obj.get("videoMimeType"),
            "videoDurationSeconds": obj.get("videoDurationSeconds"),
            "videoSizeBytes": obj.get("videoSizeBytes"),
            "videoRecordingStatus": obj.get("videoRecordingStatus"),
            "videoRecordingError": obj.get("videoRecordingError")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.call_summary import CallSummary
from keplar_api.models.invite import Invite
from keplar_api.models.invite_response_attribute import InviteResponseAttribute
from keplar_api.models.invite_response_data import InviteResponseData
from keplar_api.models.invite_response_evaluation_enum import InviteResponseEvaluationEnum
from keplar_api.models.invite_response_kind import InviteResponseKind
from keplar_api.models.invite_response_metadata import InviteResponseMetadata
from keplar_api.models.invite_response_status import InviteResponseStatus
from keplar_api.models.participant import Participant
from typing import Optional, Set
from typing_extensions import Self

class InviteResponseWithCallSummary(BaseModel):
    """
    InviteResponseWithCallSummary
    """ # noqa: E501
    id: StrictStr
    kind: InviteResponseKind
    status: InviteResponseStatus
    data: Optional[InviteResponseData] = None
    metadata: Optional[InviteResponseMetadata] = None
    evaluation: Optional[InviteResponseEvaluationEnum] = None
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    invite_id: StrictStr = Field(alias="inviteId")
    vendor_participant_id: Optional[StrictStr] = Field(default=None, alias="vendorParticipantId")
    participant_id: Optional[StrictStr] = Field(default=None, alias="participantId")
    invite: Optional[Invite] = None
    participant: Optional[Participant] = None
    calls: List[CallSummary]
    invite_response_attributes: Optional[List[InviteResponseAttribute]] = Field(default=None, alias="inviteResponseAttributes")
    __properties: ClassVar[List[str]] = ["id", "kind", "status", "data", "metadata", "evaluation", "createdAt", "updatedAt", "inviteId", "vendorParticipantId", "participantId", "invite", "participant", "calls", "inviteResponseAttributes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InviteResponseWithCallSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of invite
        if self.invite:
            _dict['invite'] = self.invite.to_dict()
        # override the default output from pydantic by calling `to_dict()` of participant
        if self.participant:
            _dict['participant'] = self.participant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in calls (list)
        _items = []
        if self.calls:
            for _item_calls in self.calls:
                if _item_calls:
                    _items.append(_item_calls.to_dict())
            _dict['calls'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invite_response_attributes (list)
        _items = []
        if self.invite_response_attributes:
            for _item_invite_response_attributes in self.invite_response_attributes:
                if _item_invite_response_attributes:
                    _items.append(_item_invite_response_attributes.to_dict())
            _dict['inviteResponseAttributes'] = _items
        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if evaluation (nullable) is None
        # and model_fields_set contains the field
        if self.evaluation is None and "evaluation" in self.model_fields_set:
            _dict['evaluation'] = None

        # set to None if vendor_participant_id (nullable) is None
        # and model_fields_set contains the field
        if self.vendor_participant_id is None and "vendor_participant_id" in self.model_fields_set:
            _dict['vendorParticipantId'] = None

        # set to None if participant_id (nullable) is None
        # and model_fields_set contains the field
        if self.participant_id is None and "participant_id" in self.model_fields_set:
            _dict['participantId'] = None

        # set to None if participant (nullable) is None
        # and model_fields_set contains the field
        if self.participant is None and "participant" in self.model_fields_set:
            _dict['participant'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InviteResponseWithCallSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "kind": obj.get("kind"),
            "status": obj.get("status"),
            "data": InviteResponseData.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "metadata": InviteResponseMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "evaluation": obj.get("evaluation"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "inviteId": obj.get("inviteId"),
            "vendorParticipantId": obj.get("vendorParticipantId"),
            "participantId": obj.get("participantId"),
            "invite": Invite.from_dict(obj["invite"]) if obj.get("invite") is not None else None,
            "participant": Participant.from_dict(obj["participant"]) if obj.get("participant") is not None else None,
            "calls": [CallSummary.from_dict(_item) for _item in obj["calls"]] if obj.get("calls") is not None else None,
            "inviteResponseAttributes": [InviteResponseAttribute.from_dict(_item) for _item in obj["inviteResponseAttributes"]] if obj.get("inviteResponseAttributes") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_code_invite_response_request import CreateCodeInviteResponseRequest

class TestCreateCodeInviteResponseRequest(unittest.TestCase):
    """CreateCodeInviteResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateCodeInviteResponseRequest:
        """Test CreateCodeInviteResponseRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateCodeInviteResponseRequest`
        """
        model = CreateCodeInviteResponseRequest()
        if include_optional:
            return CreateCodeInviteResponseRequest(
                kind = 'VOICE_CALL',
                data = keplar_api.models.invite_response_data.InviteResponseData(
                    email = '', 
                    screener_questions_responses = [
                        keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                            question = '', 
                            response = null, )
                        ], 
                    consented = True, 
                    redirected = True, )
            )
        else:
            return CreateCodeInviteResponseRequest(
        )
        """

    def testCreateCodeInviteResponseRequest(self):
        """Test CreateCodeInviteResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_projects_project_id_analysis_post200_response import ApiProjectsProjectIdAnalysisPost200Response

class TestApiProjectsProjectIdAnalysisPost200Response(unittest.TestCase):
    """ApiProjectsProjectIdAnalysisPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiProjectsProjectIdAnalysisPost200Response:
        """Test ApiProjectsProjectIdAnalysisPost200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiProjectsProjectIdAnalysisPost200Response`
        """
        model = ApiProjectsProjectIdAnalysisPost200Response()
        if include_optional:
            return ApiProjectsProjectIdAnalysisPost200Response(
                artifact_id = ''
            )
        else:
            return ApiProjectsProjectIdAnalysisPost200Response(
        )
        """

    def testApiProjectsProjectIdAnalysisPost200Response(self):
        """Test ApiProjectsProjectIdAnalysisPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.search_users200_response import SearchUsers200Response

class TestSearchUsers200Response(unittest.TestCase):
    """SearchUsers200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchUsers200Response:
        """Test SearchUsers200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchUsers200Response`
        """
        model = SearchUsers200Response()
        if include_optional:
            return SearchUsers200Response(
                users = [
                    keplar_api.models.user_search_result.UserSearchResult(
                        id = '', 
                        email = '', 
                        name = '', 
                        account_status = 'ACTIVE', 
                        data = null, 
                        org_id = '', 
                        org = keplar_api.models.user_org.UserOrg(
                            id = '', 
                            name = '', ), 
                        projects = [
                            keplar_api.models.user_project.UserProject(
                                id = '', 
                                name = '', )
                            ], 
                        default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                            id = '', 
                            name = '', ), 
                        created_at = '', )
                    ]
            )
        else:
            return SearchUsers200Response(
                users = [
                    keplar_api.models.user_search_result.UserSearchResult(
                        id = '', 
                        email = '', 
                        name = '', 
                        account_status = 'ACTIVE', 
                        data = null, 
                        org_id = '', 
                        org = keplar_api.models.user_org.UserOrg(
                            id = '', 
                            name = '', ), 
                        projects = [
                            keplar_api.models.user_project.UserProject(
                                id = '', 
                                name = '', )
                            ], 
                        default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                            id = '', 
                            name = '', ), 
                        created_at = '', )
                    ],
        )
        """

    def testSearchUsers200Response(self):
        """Test SearchUsers200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_participant_invites_post_request import ApiInvitesIdParticipantInvitesPostRequest

class TestApiInvitesIdParticipantInvitesPostRequest(unittest.TestCase):
    """ApiInvitesIdParticipantInvitesPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdParticipantInvitesPostRequest:
        """Test ApiInvitesIdParticipantInvitesPostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdParticipantInvitesPostRequest`
        """
        model = ApiInvitesIdParticipantInvitesPostRequest()
        if include_optional:
            return ApiInvitesIdParticipantInvitesPostRequest(
                participant = keplar_api.models._api_invites__id__participant_invites_post_request_participant._api_invites__id__participantInvites_post_request_participant(
                    id = '', 
                    name = '', 
                    email = '', 
                    phone_number = '01234', 
                    config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                        send_invite_email = True, 
                        show_call_metadata = True, 
                        is_test_invite = True, ), )
            )
        else:
            return ApiInvitesIdParticipantInvitesPostRequest(
                participant = keplar_api.models._api_invites__id__participant_invites_post_request_participant._api_invites__id__participantInvites_post_request_participant(
                    id = '', 
                    name = '', 
                    email = '', 
                    phone_number = '01234', 
                    config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                        send_invite_email = True, 
                        show_call_metadata = True, 
                        is_test_invite = True, ), ),
        )
        """

    def testApiInvitesIdParticipantInvitesPostRequest(self):
        """Test ApiInvitesIdParticipantInvitesPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_project_shares200_response import GetProjectShares200Response

class TestGetProjectShares200Response(unittest.TestCase):
    """GetProjectShares200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetProjectShares200Response:
        """Test GetProjectShares200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetProjectShares200Response`
        """
        model = GetProjectShares200Response()
        if include_optional:
            return GetProjectShares200Response(
                share_entities = [
                    keplar_api.models.share_entity.ShareEntity(
                        id = '', 
                        token = '', 
                        entity_kind = 'project', 
                        entity_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_count = 1.337, 
                        is_active = True, 
                        created_by_kind = 'participant', 
                        created_by_id = '', 
                        config = null, 
                        email_shares = [
                            keplar_api.models.email_share.EmailShare(
                                id = '', 
                                email = '', 
                                share_entity_id = '', 
                                access_token = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                share_entity = keplar_api.models.share_entity.ShareEntity(
                                    id = '', 
                                    token = '', 
                                    entity_kind = 'project', 
                                    entity_id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    access_count = 1.337, 
                                    is_active = True, 
                                    created_by_id = '', 
                                    config = null, ), )
                            ], )
                    ],
                total = 1.337
            )
        else:
            return GetProjectShares200Response(
                share_entities = [
                    keplar_api.models.share_entity.ShareEntity(
                        id = '', 
                        token = '', 
                        entity_kind = 'project', 
                        entity_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        access_count = 1.337, 
                        is_active = True, 
                        created_by_kind = 'participant', 
                        created_by_id = '', 
                        config = null, 
                        email_shares = [
                            keplar_api.models.email_share.EmailShare(
                                id = '', 
                                email = '', 
                                share_entity_id = '', 
                                access_token = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                share_entity = keplar_api.models.share_entity.ShareEntity(
                                    id = '', 
                                    token = '', 
                                    entity_kind = 'project', 
                                    entity_id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    access_count = 1.337, 
                                    is_active = True, 
                                    created_by_id = '', 
                                    config = null, ), )
                            ], )
                    ],
                total = 1.337,
        )
        """

    def testGetProjectShares200Response(self):
        """Test GetProjectShares200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Attribute(BaseModel):
    """
    Attribute
    """ # noqa: E501
    id: StrictStr
    attribute_kind_id: StrictStr = Field(alias="attributeKindId")
    value: StrictStr
    description: Optional[StrictStr] = None
    created_at: datetime = Field(alias="createdAt")
    attribute_kind: Optional[AttributeKind] = Field(default=None, alias="attributeKind")
    participant_attributes: Optional[List[ParticipantAttribute]] = Field(default=None, alias="participantAttributes")
    invite_response_attributes: Optional[List[InviteResponseAttribute]] = Field(default=None, alias="inviteResponseAttributes")
    __properties: ClassVar[List[str]] = ["id", "attributeKindId", "value", "description", "createdAt", "attributeKind", "participantAttributes", "inviteResponseAttributes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Attribute from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of attribute_kind
        if self.attribute_kind:
            _dict['attributeKind'] = self.attribute_kind.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in participant_attributes (list)
        _items = []
        if self.participant_attributes:
            for _item_participant_attributes in self.participant_attributes:
                if _item_participant_attributes:
                    _items.append(_item_participant_attributes.to_dict())
            _dict['participantAttributes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in invite_response_attributes (list)
        _items = []
        if self.invite_response_attributes:
            for _item_invite_response_attributes in self.invite_response_attributes:
                if _item_invite_response_attributes:
                    _items.append(_item_invite_response_attributes.to_dict())
            _dict['inviteResponseAttributes'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Attribute from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "attributeKindId": obj.get("attributeKindId"),
            "value": obj.get("value"),
            "description": obj.get("description"),
            "createdAt": obj.get("createdAt"),
            "attributeKind": AttributeKind.from_dict(obj["attributeKind"]) if obj.get("attributeKind") is not None else None,
            "participantAttributes": [ParticipantAttribute.from_dict(_item) for _item in obj["participantAttributes"]] if obj.get("participantAttributes") is not None else None,
            "inviteResponseAttributes": [InviteResponseAttribute.from_dict(_item) for _item in obj["inviteResponseAttributes"]] if obj.get("inviteResponseAttributes") is not None else None
        })
        return _obj

from keplar_api.models.attribute_kind import AttributeKind
from keplar_api.models.invite_response_attribute import InviteResponseAttribute
from keplar_api.models.participant_attribute import ParticipantAttribute
# TODO: Rewrite to not use raise_errors
Attribute.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_responses_post_request import ApiInvitesIdResponsesPostRequest

class TestApiInvitesIdResponsesPostRequest(unittest.TestCase):
    """ApiInvitesIdResponsesPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdResponsesPostRequest:
        """Test ApiInvitesIdResponsesPostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdResponsesPostRequest`
        """
        model = ApiInvitesIdResponsesPostRequest()
        if include_optional:
            return ApiInvitesIdResponsesPostRequest(
                kind = 'VOICE_CALL',
                participant_invite_code = '',
                data = keplar_api.models.invite_response_data.InviteResponseData(
                    email = '', 
                    screener_questions_responses = [
                        keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                            question = '', 
                            response = null, )
                        ], 
                    consented = True, 
                    redirected = True, )
            )
        else:
            return ApiInvitesIdResponsesPostRequest(
        )
        """

    def testApiInvitesIdResponsesPostRequest(self):
        """Test ApiInvitesIdResponsesPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_conversation_config import ProjectConversationConfig

class TestProjectConversationConfig(unittest.TestCase):
    """ProjectConversationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectConversationConfig:
        """Test ProjectConversationConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectConversationConfig`
        """
        model = ProjectConversationConfig()
        if include_optional:
            return ProjectConversationConfig(
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
                language = 'en'
            )
        else:
            return ProjectConversationConfig(
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
        )
        """

    def testProjectConversationConfig(self):
        """Test ProjectConversationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.share_entity import ShareEntity

class TestShareEntity(unittest.TestCase):
    """ShareEntity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShareEntity:
        """Test ShareEntity
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShareEntity`
        """
        model = ShareEntity()
        if include_optional:
            return ShareEntity(
                id = '',
                token = '',
                entity_kind = 'project',
                entity_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                access_count = 1.337,
                is_active = True,
                created_by_kind = 'participant',
                created_by_id = '',
                config = None,
                email_shares = [
                    keplar_api.models.email_share.EmailShare(
                        id = '', 
                        email = '', 
                        share_entity_id = '', 
                        access_token = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        share_entity = keplar_api.models.share_entity.ShareEntity(
                            id = '', 
                            token = '', 
                            entity_kind = 'project', 
                            entity_id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            access_count = 1.337, 
                            is_active = True, 
                            created_by_kind = 'participant', 
                            created_by_id = '', 
                            config = null, 
                            email_shares = [
                                keplar_api.models.email_share.EmailShare(
                                    id = '', 
                                    email = '', 
                                    share_entity_id = '', 
                                    access_token = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                ], ), )
                    ]
            )
        else:
            return ShareEntity(
                id = '',
                token = '',
                entity_kind = 'project',
                entity_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                access_count = 1.337,
                is_active = True,
                config = None,
        )
        """

    def testShareEntity(self):
        """Test ShareEntity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.artifact_data import ArtifactData
from keplar_api.models.artifact_kind import ArtifactKind
from keplar_api.models.artifact_metadata import ArtifactMetadata
from typing import Optional, Set
from typing_extensions import Self

class Artifact(BaseModel):
    """
    Artifact
    """ # noqa: E501
    id: StrictStr
    title: Optional[StrictStr] = None
    kind: ArtifactKind
    project_id: Optional[StrictStr] = Field(default=None, alias="projectId")
    attribute_kind_group_id: Optional[StrictStr] = Field(default=None, alias="attributeKindGroupId")
    version_group_id: StrictStr = Field(alias="versionGroupId")
    data: Optional[ArtifactData] = None
    metadata: ArtifactMetadata
    created_by_id: StrictStr = Field(alias="createdById")
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    project: Optional[Project] = None
    attribute_kind_group: Optional[AttributeKindGroup] = Field(default=None, alias="attributeKindGroup")
    version_group: Optional[ArtifactVersionGroup] = Field(default=None, alias="versionGroup")
    latest_for_group: Optional[ArtifactVersionGroup] = Field(default=None, alias="latestForGroup")
    created_by: Optional[User] = Field(default=None, alias="createdBy")
    __properties: ClassVar[List[str]] = ["id", "title", "kind", "projectId", "attributeKindGroupId", "versionGroupId", "data", "metadata", "createdById", "createdAt", "updatedAt", "project", "attributeKindGroup", "versionGroup", "latestForGroup", "createdBy"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Artifact from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of attribute_kind_group
        if self.attribute_kind_group:
            _dict['attributeKindGroup'] = self.attribute_kind_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of version_group
        if self.version_group:
            _dict['versionGroup'] = self.version_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_for_group
        if self.latest_for_group:
            _dict['latestForGroup'] = self.latest_for_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if project_id (nullable) is None
        # and model_fields_set contains the field
        if self.project_id is None and "project_id" in self.model_fields_set:
            _dict['projectId'] = None

        # set to None if attribute_kind_group_id (nullable) is None
        # and model_fields_set contains the field
        if self.attribute_kind_group_id is None and "attribute_kind_group_id" in self.model_fields_set:
            _dict['attributeKindGroupId'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if project (nullable) is None
        # and model_fields_set contains the field
        if self.project is None and "project" in self.model_fields_set:
            _dict['project'] = None

        # set to None if attribute_kind_group (nullable) is None
        # and model_fields_set contains the field
        if self.attribute_kind_group is None and "attribute_kind_group" in self.model_fields_set:
            _dict['attributeKindGroup'] = None

        # set to None if latest_for_group (nullable) is None
        # and model_fields_set contains the field
        if self.latest_for_group is None and "latest_for_group" in self.model_fields_set:
            _dict['latestForGroup'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Artifact from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "kind": obj.get("kind"),
            "projectId": obj.get("projectId"),
            "attributeKindGroupId": obj.get("attributeKindGroupId"),
            "versionGroupId": obj.get("versionGroupId"),
            "data": ArtifactData.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "metadata": ArtifactMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "createdById": obj.get("createdById"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "attributeKindGroup": AttributeKindGroup.from_dict(obj["attributeKindGroup"]) if obj.get("attributeKindGroup") is not None else None,
            "versionGroup": ArtifactVersionGroup.from_dict(obj["versionGroup"]) if obj.get("versionGroup") is not None else None,
            "latestForGroup": ArtifactVersionGroup.from_dict(obj["latestForGroup"]) if obj.get("latestForGroup") is not None else None,
            "createdBy": User.from_dict(obj["createdBy"]) if obj.get("createdBy") is not None else None
        })
        return _obj

from keplar_api.models.artifact_version_group import ArtifactVersionGroup
from keplar_api.models.attribute_kind_group import AttributeKindGroup
from keplar_api.models.project import Project
from keplar_api.models.user import User
# TODO: Rewrite to not use raise_errors
Artifact.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class ConversationMessage(BaseModel):
    """
    ConversationMessage
    """ # noqa: E501
    call_id: StrictStr = Field(alias="callId")
    index: Union[StrictFloat, StrictInt]
    role: StrictStr
    source: Optional[StrictStr] = None
    time: datetime
    end_time: datetime = Field(alias="endTime")
    message: StrictStr
    duration: Union[StrictFloat, StrictInt]
    seconds_from_start: Union[StrictFloat, StrictInt] = Field(alias="secondsFromStart")
    conversation_message_topic_index: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="conversationMessageTopicIndex")
    call: Optional[Call] = None
    conversation_message_topic: Optional[ConversationMessageTopic] = Field(default=None, alias="conversationMessageTopic")
    __properties: ClassVar[List[str]] = ["callId", "index", "role", "source", "time", "endTime", "message", "duration", "secondsFromStart", "conversationMessageTopicIndex", "call", "conversationMessageTopic"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ConversationMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of call
        if self.call:
            _dict['call'] = self.call.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation_message_topic
        if self.conversation_message_topic:
            _dict['conversationMessageTopic'] = self.conversation_message_topic.to_dict()
        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict['source'] = None

        # set to None if conversation_message_topic_index (nullable) is None
        # and model_fields_set contains the field
        if self.conversation_message_topic_index is None and "conversation_message_topic_index" in self.model_fields_set:
            _dict['conversationMessageTopicIndex'] = None

        # set to None if conversation_message_topic (nullable) is None
        # and model_fields_set contains the field
        if self.conversation_message_topic is None and "conversation_message_topic" in self.model_fields_set:
            _dict['conversationMessageTopic'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ConversationMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "callId": obj.get("callId"),
            "index": obj.get("index"),
            "role": obj.get("role"),
            "source": obj.get("source"),
            "time": obj.get("time"),
            "endTime": obj.get("endTime"),
            "message": obj.get("message"),
            "duration": obj.get("duration"),
            "secondsFromStart": obj.get("secondsFromStart"),
            "conversationMessageTopicIndex": obj.get("conversationMessageTopicIndex"),
            "call": Call.from_dict(obj["call"]) if obj.get("call") is not None else None,
            "conversationMessageTopic": ConversationMessageTopic.from_dict(obj["conversationMessageTopic"]) if obj.get("conversationMessageTopic") is not None else None
        })
        return _obj

from keplar_api.models.call import Call
from keplar_api.models.conversation_message_topic import ConversationMessageTopic
# TODO: Rewrite to not use raise_errors
ConversationMessage.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_response_attribute_data import InviteResponseAttributeData

class TestInviteResponseAttributeData(unittest.TestCase):
    """InviteResponseAttributeData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteResponseAttributeData:
        """Test InviteResponseAttributeData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteResponseAttributeData`
        """
        model = InviteResponseAttributeData()
        if include_optional:
            return InviteResponseAttributeData(
                evidence = keplar_api.models.evidence.Evidence(
                    verbatims = '', 
                    confidence = 1.337, 
                    message_index = 1.337, ),
                observations = [
                    ''
                    ]
            )
        else:
            return InviteResponseAttributeData(
        )
        """

    def testInviteResponseAttributeData(self):
        """Test InviteResponseAttributeData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.block_content_node import BlockContentNode

class TestBlockContentNode(unittest.TestCase):
    """BlockContentNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BlockContentNode:
        """Test BlockContentNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BlockContentNode`
        """
        model = BlockContentNode()
        if include_optional:
            return BlockContentNode(
                type = 'paragraph',
                content = [
                    keplar_api.models.list_item_node.ListItemNode(
                        type = 'listItem', )
                    ],
                attrs = keplar_api.models.ordered_list_attrs.OrderedListAttrs(
                    start = 1.337, )
            )
        else:
            return BlockContentNode(
                type = 'paragraph',
        )
        """

    def testBlockContentNode(self):
        """Test BlockContentNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_customers201_response import InviteCustomers201Response

class TestInviteCustomers201Response(unittest.TestCase):
    """InviteCustomers201Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteCustomers201Response:
        """Test InviteCustomers201Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteCustomers201Response`
        """
        model = InviteCustomers201Response()
        if include_optional:
            return InviteCustomers201Response(
                invited = [
                    keplar_api.models.invited_user.InvitedUser(
                        id = '', 
                        email = '', 
                        name = '', )
                    ],
                org = keplar_api.models.invite_org_result.InviteOrgResult(
                    id = '', 
                    name = '', 
                    domain = '', 
                    is_new = True, ),
                workspace = keplar_api.models.invite_workspace_result.InviteWorkspaceResult(
                    id = '', 
                    name = '', 
                    is_new = True, ),
                skipped = [
                    keplar_api.models.skipped_customer.SkippedCustomer(
                        email = '', 
                        reason = '', )
                    ]
            )
        else:
            return InviteCustomers201Response(
                invited = [
                    keplar_api.models.invited_user.InvitedUser(
                        id = '', 
                        email = '', 
                        name = '', )
                    ],
                org = keplar_api.models.invite_org_result.InviteOrgResult(
                    id = '', 
                    name = '', 
                    domain = '', 
                    is_new = True, ),
                skipped = [
                    keplar_api.models.skipped_customer.SkippedCustomer(
                        email = '', 
                        reason = '', )
                    ],
        )
        """

    def testInviteCustomers201Response(self):
        """Test InviteCustomers201Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
